@@ -1,14 +1,14 @@
 use poem::{
     http::{Method, StatusCode, Uri},
     web::Data,
-    Endpoint, EndpointExt, IntoEndpoint,
+    Endpoint, EndpointExt, Error, IntoEndpoint,
 };
 use poem_openapi::{
     param::Query,
     payload::{Binary, Json, PlainText},
     registry::{MetaApi, MetaSchema},
     types::Type,
-    ApiRequest, ApiResponse, OpenApi, OpenApiService, ParseRequestError, Tags,
+    ApiRequest, ApiResponse, OpenApi, OpenApiService, Tags,
 };
 
 #[tokio::test]
@@ -33,7 +33,8 @@ async fn path_and_method() {
                 .uri(Uri::from_static("/abc"))
                 .finish(),
         )
-        .await;
+        .await
+        .unwrap();
     assert_eq!(resp.status(), StatusCode::OK);
 }
 
@@ -112,7 +113,8 @@ async fn common_attributes() {
                 .uri(Uri::from_static("/hello/world"))
                 .finish(),
         )
-        .await;
+        .await
+        .unwrap();
     assert_eq!(resp.status(), StatusCode::OK);
 }
 
@@ -178,7 +180,8 @@ async fn request() {
                 .content_type("application/json")
                 .body("100"),
         )
-        .await;
+        .await
+        .unwrap();
     assert_eq!(resp.status(), StatusCode::OK);
 
     let resp = ep
@@ -189,7 +192,8 @@ async fn request() {
                 .content_type("text/plain")
                 .body("abc"),
         )
-        .await;
+        .await
+        .unwrap();
     assert_eq!(resp.status(), StatusCode::OK);
 
     let resp = ep
@@ -200,7 +204,8 @@ async fn request() {
                 .content_type("application/octet-stream")
                 .body(vec![1, 2, 3]),
         )
-        .await;
+        .await
+        .unwrap();
     assert_eq!(resp.status(), StatusCode::OK);
 }
 
@@ -232,10 +237,11 @@ async fn payload_request() {
                 .content_type("application/json")
                 .body("100"),
         )
-        .await;
+        .await
+        .unwrap();
     assert_eq!(resp.status(), StatusCode::OK);
 
-    let resp = ep
+    let err = ep
         .call(
             poem::Request::builder()
                 .method(Method::POST)
@@ -243,8 +249,9 @@ async fn payload_request() {
                 .content_type("text/plain")
                 .body("100"),
         )
-        .await;
-    assert_eq!(resp.status(), StatusCode::METHOD_NOT_ALLOWED);
+        .await
+        .unwrap_err();
+    assert_eq!(err.status(), StatusCode::METHOD_NOT_ALLOWED);
 }
 
 #[tokio::test]
@@ -275,7 +282,8 @@ async fn optional_payload_request() {
                 .content_type("application/json")
                 .body("100"),
         )
-        .await;
+        .await
+        .unwrap();
     assert_eq!(resp.status(), StatusCode::OK);
     assert_eq!(resp.into_body().into_string().await.unwrap(), "100");
 
@@ -288,7 +296,8 @@ async fn optional_payload_request() {
                 .content_type("application/json")
                 .finish(),
         )
-        .await;
+        .await
+        .unwrap();
     assert_eq!(resp.status(), StatusCode::OK);
     assert_eq!(resp.into_body().into_string().await.unwrap(), "999");
 }
@@ -361,7 +370,8 @@ async fn response() {
                 .uri(Uri::from_static("/?code=200"))
                 .finish(),
         )
-        .await;
+        .await
+        .unwrap();
     assert_eq!(resp.status(), StatusCode::OK);
     assert_eq!(resp.take_body().into_string().await.unwrap(), "");
 
@@ -372,7 +382,8 @@ async fn response() {
                 .uri(Uri::from_static("/?code=409"))
                 .finish(),
         )
-        .await;
+        .await
+        .unwrap();
     assert_eq!(resp.status(), StatusCode::CONFLICT);
     assert_eq!(resp.content_type(), Some("application/json"));
     assert_eq!(resp.take_body().into_string().await.unwrap(), "409");
@@ -384,7 +395,8 @@ async fn response() {
                 .uri(Uri::from_static("/?code=404"))
                 .finish(),
         )
-        .await;
+        .await
+        .unwrap();
     assert_eq!(resp.status(), StatusCode::NOT_FOUND);
     assert_eq!(resp.content_type(), Some("text/plain"));
     assert_eq!(resp.take_body().into_string().await.unwrap(), "code: 404");
@@ -403,7 +415,7 @@ async fn bad_request_handler() {
         BadRequest(PlainText<String>),
     }
 
-    fn bad_request_handler(err: ParseRequestError) -> MyResponse {
+    fn bad_request_handler(err: Error) -> MyResponse {
         MyResponse::BadRequest(PlainText(format!("!!! {}", err.to_string())))
     }
 
@@ -426,7 +438,8 @@ async fn bad_request_handler() {
                 .uri(Uri::from_static("/?code=200"))
                 .finish(),
         )
-        .await;
+        .await
+        .unwrap();
     assert_eq!(resp.status(), StatusCode::OK);
     assert_eq!(resp.content_type(), Some("text/plain"));
     assert_eq!(resp.take_body().into_string().await.unwrap(), "code: 200");
@@ -438,12 +451,13 @@ async fn bad_request_handler() {
                 .uri(Uri::from_static("/"))
                 .finish(),
         )
-        .await;
+        .await
+        .unwrap();
     assert_eq!(resp.status(), StatusCode::BAD_REQUEST);
     assert_eq!(resp.content_type(), Some("text/plain"));
     assert_eq!(
         resp.take_body().into_string().await.unwrap(),
-        r#"!!! Failed to parse parameter `code`: Type "integer(uint16)" expects an input value."#
+        r#"!!! failed to parse parameter `code`: Type "integer(uint16)" expects an input value."#
     );
 }
 
@@ -460,7 +474,7 @@ async fn bad_request_handler_for_validator() {
         BadRequest(PlainText<String>),
     }
 
-    fn bad_request_handler(err: ParseRequestError) -> MyResponse {
+    fn bad_request_handler(err: Error) -> MyResponse {
         MyResponse::BadRequest(PlainText(format!("!!! {}", err.to_string())))
     }
 
@@ -486,7 +500,8 @@ async fn bad_request_handler_for_validator() {
                 .uri(Uri::from_static("/?code=50"))
                 .finish(),
         )
-        .await;
+        .await
+        .unwrap();
     assert_eq!(resp.status(), StatusCode::OK);
     assert_eq!(resp.content_type(), Some("text/plain"));
     assert_eq!(resp.take_body().into_string().await.unwrap(), "code: 50");
@@ -498,12 +513,13 @@ async fn bad_request_handler_for_validator() {
                 .uri(Uri::from_static("/?code=200"))
                 .finish(),
         )
-        .await;
+        .await
+        .unwrap();
     assert_eq!(resp.status(), StatusCode::BAD_REQUEST);
     assert_eq!(resp.content_type(), Some("text/plain"));
     assert_eq!(
         resp.take_body().into_string().await.unwrap(),
-        r#"!!! Failed to parse parameter `code`: verification failed. maximum(100, exclusive: false)"#
+        r#"!!! failed to parse parameter `code`: verification failed. maximum(100, exclusive: false)"#
     );
 }
 
@@ -529,7 +545,8 @@ async fn poem_extract() {
                 .uri(Uri::from_static("/"))
                 .finish(),
         )
-        .await;
+        .await
+        .unwrap();
     assert_eq!(resp.status(), StatusCode::OK);
 }
 
@@ -583,7 +600,8 @@ async fn returning_borrowed_value() {
                 .uri(Uri::from_static("/value1"))
                 .finish(),
         )
-        .await;
+        .await
+        .unwrap();
     assert_eq!(resp.status(), StatusCode::OK);
     assert_eq!(resp.into_body().into_string().await.unwrap(), "999");
 
@@ -594,7 +612,8 @@ async fn returning_borrowed_value() {
                 .uri(Uri::from_static("/value2"))
                 .finish(),
         )
-        .await;
+        .await
+        .unwrap();
     assert_eq!(resp.status(), StatusCode::OK);
     assert_eq!(resp.into_body().into_string().await.unwrap(), "\"abc\"");
 
@@ -605,7 +624,8 @@ async fn returning_borrowed_value() {
                 .uri(Uri::from_static("/value3"))
                 .finish(),
         )
-        .await;
+        .await
+        .unwrap();
     assert_eq!(resp.status(), StatusCode::OK);
     assert_eq!(resp.into_body().into_string().await.unwrap(), "888");
 
@@ -616,7 +636,8 @@ async fn returning_borrowed_value() {
                 .uri(Uri::from_static("/values"))
                 .finish(),
         )
-        .await;
+        .await
+        .unwrap();
     assert_eq!(resp.status(), StatusCode::OK);
     assert_eq!(resp.into_body().into_string().await.unwrap(), "[1,2,3,4,5]");
 }
